package net.wanji.opt.controllerv2.judgeanalysis;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemOverview;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.areaproblem.AreaProblemTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.crossproblem.CrossProblemDirTrendAnalysisResult;
import net.wanji.opt.controllerv2.judgeanalysis.design.response.crossproblem.CrossProblemTimeDirReasonResult;
import net.wanji.opt.servicev2.judgeanalysis.AnalysisProblemCrossDayService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;

/**
* <p>
* 路口问题分析 前端控制器
* </p>
*
* @author fengyi
* @since 2025-03-13
*/
@Api(tags = "研判分析-路口问题分析")
@RestController
@RequestMapping("/analysis-problem-cross-day")
public class AnalysisProblemCrossDayController {


    @Autowired
    private AnalysisProblemCrossDayService analysisProblemCrossDayService;



    @ApiOperation(value = "单路口-问题数量总览",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String", defaultValue = ""),
            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = true, dataType = "int", defaultValue = "1"),
    })
    @GetMapping(value = "/overview")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemOverview.class),
    })
    public JsonViewObject problemOverview(String crossId,Integer timeType) {
        return JsonViewObject.newInstance().success(null);
    }


    @ApiOperation(value = "单路口-路口报警走势",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String", defaultValue = ""),
            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = true, dataType = "int", defaultValue = "1"),
    })
    @GetMapping(value = "/trend")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemTrendAnalysisResult.class),
    })
    public JsonViewObject trend(String crossId,Integer timeType) {
        return JsonViewObject.newInstance().success(null);
    }



    @ApiOperation(value = "单路口-问题发生时段、方向、原因分析",   response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String", defaultValue = ""),
            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = true, dataType = "int", defaultValue = "1"),
    })
    @GetMapping(value = "/detail")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = CrossProblemTimeDirReasonResult.class),
    })
    public JsonViewObject detail(String crossId,String timeType) {
        return JsonViewObject.newInstance().success(null);
    }


    @ApiOperation(value = "单路口-各方向问题情况分布",   response = CrossProblemDirTrendAnalysisResult.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "crossId", value = "路口ID", required = true, dataType = "String", defaultValue = ""),
            @ApiImplicitParam(name = "timeType", value = "事件类型 1：近一个月 2：近一周", required = true, dataType = "int", defaultValue = "1"),
            @ApiImplicitParam(name = "eventType", value = "事件代码 701：空放 702：路口失衡，703：路口溢出 707：路口拥堵", required = true, dataType = "String", defaultValue = "")
    })
    @GetMapping(value = "/dir-trend")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = AreaProblemTrendAnalysisResult.class),
    })
    public JsonViewObject dirTrend(String crossId,String timeType,String eventType) {
        return JsonViewObject.newInstance().success(null);
    }


}