package net.wanji.opt.servicev2.implv2;

import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.utils.tool.StringUtils;
import net.wanji.opt.dao.mapper.CrossMapper;
import net.wanji.opt.dao.mapper.GreenwaveHistoryMapper;
import net.wanji.opt.po.base.CrossLaneDataHistPoExtend;
import net.wanji.opt.servicev2.CrossService;
import net.wanji.opt.synthesis.pojo.CrossRealTimeAlarmEntity;
import net.wanji.opt.synthesis.pojo.CrossStatusDisOptTimeEntity;
import net.wanji.opt.synthesis.pojo.StrategyCrossResultEntity;
import net.wanji.opt.vo2.CrossStatusDistributionVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestParam;

import javax.annotation.Resource;
import java.util.*;

/**
 * <p>
 *     监测详情-路口事件详情
 * @author zhengyifan
 * @date 2025/3/15
 */
@Service
@Slf4j
public class CrossServiceImpl implements CrossService {
    @Resource
    private CrossMapper crossMapper;
    @Resource
    private GreenwaveHistoryMapper greenwaveHistoryMapper;

    /**
     * 路口状态分布
     * @param crossID 路口ID
     * @param date 日期
     * @param groupType 时间粒度 参数要求：0--5分钟 1--15分钟 2--30分钟 3--60分钟
     * @param objectType 范围 参数要求：1--方向级 2--转向级 3--车道级 4--路口级
     * @param directionName 方向
     * @return
     */
    @Override
    public Map<String, List<?>> getCrossStatusDistribution(String crossID, String date, String groupType, Integer objectType, String directionName) {
        Map<String, Object> params = new HashMap<>();
        params.put("crossId", crossID);
        params.put("startDate", date+" 00:00:00");
        params.put("endDate", date + " 23:59:59");
        params.put("groupType", groupType);
        params.put("objectType", objectType);
        if (StringUtils.isNotBlank(directionName)) {
            params.put("dir", BaseEnum.SignalDirectionEnum.getCodeByName(directionName.substring(0, directionName.indexOf("进口"))));
        }

        List<CrossLaneDataHistPoExtend> firstList = greenwaveHistoryMapper.findCrossObjectIndex(params);
        List<CrossStatusDisOptTimeEntity> optTimeList = crossMapper.getOptTimes(crossID);
        List<CrossStatusDistributionVO> infoList = new ArrayList<>();

        for (CrossLaneDataHistPoExtend c : firstList) {
            CrossStatusDistributionVO info = new CrossStatusDistributionVO();
            info.setSpeed(c.getSpeed());
            info.setQueueLength(c.getAvgQueueLength());
            info.setDelayTime(c.getDelayTime());
            info.setStopTimes(c.getStopTimes());

            info.setStartTime(c.getStartTime().toString().substring(11,16));
            infoList.add(info);
        }

        Map<String, List<?>> result = new HashMap<>();
        result.put("infoList", infoList);
        result.put("optTimeList", optTimeList);

        return result;
    }

    /**
     * 路口实时告警
     * @param crossID
     * @param time 可选参数
     * @return
     */
    @Override
    public List<CrossRealTimeAlarmEntity> getCrossRealTimeAlarm(String crossID, String time) {
        return crossMapper.getCrossRealTimeAlarms(crossID, time);
    }
}
